<!DOCTYPE TS><TS>
<context>
    <name>AddLnk</name>
    <message>
        <source>Add a &quot;Catalog Link&quot; to the database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Location of the .hcf file:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CdCat databases (*.hcf )</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open a file...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CdCatConfig</name>
    <message>
        <source>Error during autoload...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>I can&apos;t open the autoload catalog.
Check the file, or change the autoload option in the config dialog!
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>I can&apos;t open the autoload catalog according the first command line parameter.
Check the file!
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>I can&apos;t get the $HOME environment variable.
It is necessary couse I&apos;d like to save the config file into your home directory.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>I can&apos;t create or rewrite the ./cdcat.cfg file </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>I can&apos;t create or rewrite the $(HOME)/.cdcatconfig file </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error while saving config file...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CdCatMainWidget</name>
    <message>
        <source>Directory Tree</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save As...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add media...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rescan media...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Insert Catalog...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename node...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete node</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort media by number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort media by name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort media by type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort media by time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Seek in database...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Node size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configuration...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Catalog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Others</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hyper&apos;s CD Catalogizer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open a catalog from a file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close the actual catalog.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add a new media to the catalog.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete the selected media from the catalog.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configuration of the program.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create a new, empty catalog and close the previous.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search an element in the database(catalog).You can search filenames, directory names, name parts or mp3 tags etc...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search an element.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recent files...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import/Export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Re-Number media node...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import database (csv/gtktalog)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Borrowing info...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save all modifications to the disc.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save the catalog to a new file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add a link to a CdCAt Catalog...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set Colors...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No item selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rescan the selected media.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Seek in the panel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ColorSchemePreview</name>
    <message>
        <source>Title:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Road To Hell</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ColorSettings</name>
    <message>
        <source>ColorSettings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Comment area background and the file higlighting line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Frame of comment area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Comment window static text (Program text)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Comment window variable text (Data)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blue:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CommentWidget</name>
    <message>
        <source>Edit and refresh the actual comment page.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Upper container! (..)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> CdCat Catalog root</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Owner:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media (number/name):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mp3-Tag:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(Art/Tit/Alb/Year/Comm)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shows the content of the file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There is no selected element.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> Link to a CdCat catalog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Location:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last modification:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <source>Configure  CdCat...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Autoload DataBase on startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save the XML-db.file nicer format(needs more space)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Application font size.(must restart cdcat!) </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CdCat Databases (*.hcf)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Path to cdrom device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scanning: mount cdrom at start / eject when finish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use own font size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number of history entries</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose path to cdrom!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The language of CdCat interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose a file to load automatically!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatically save the database after every scan (for dafety sake)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select additional items to read</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DataBase</name>
    <message>
        <source>I can&apos;t rewrite the file: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>I can&apos;t create the file: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>I can&apos;t open the file: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot read directory: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ignore directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel scanning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Symbolic link#Points to:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error while parsing file: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No database opened!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DirectoryView</name>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GuiSlave</name>
    <message>
        <source>Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Catalog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown(DB)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DVD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>HardDisc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Floppy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NetworkDrv</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FlashDrv</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OtherDevice</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hyper&apos;s CD Catalogizer (modified)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hyper&apos;s CD Catalogizer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CdCat databases (*.hcf )</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open a file...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error while opening...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save to file...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error while saving...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Closing previous database...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you want to save the changes?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you really want to delete this?: 
%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Confirmation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warning...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can refresh ONLY a MEDIA node!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Insert a database file...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The size of &quot;%1&quot; : 
 %2 
 %3 file /%4 directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot mount CD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot eject CD!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>I can&apos;t find the &quot;mount&quot; program</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot mount CD!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot eject CD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>I can&apos;t find the &quot;eject&quot; program</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename node...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete node</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rescan media...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add media...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Insert Catalog...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rescan %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Re-Number media...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>It is NOT a media node!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Node size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View/Edit Comment...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close all branch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show/Remove Content...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There is no selected item in the middle list box!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>An error occured while scanning,
the DataBase may be incomplete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There is no selected Media in the middle list box!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>An error occured while scanning, the rescan operation was cancelled: 
%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Borrow this media to...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you want to clear the borrowing mark from media &quot;%1&quot;?
(Say yes if you got it back.)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>I got it back! (clear borrowing mark)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Catalog Link</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Follow the link (Open it) !</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add a link to a CdCAt Catalog...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The link is empty.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The database file has newer version than this version of cdcat can work with:
I understand maximum %1 datafile version but readed %2

Strongly recommended to upgrade your cdcat!!!
Homepage: %3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No database opened.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No item selected.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The resoult:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HDirectoryView</name>
    <message>
        <source>Directory Tree</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Link</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Drop target</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not implemented</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Drag source</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HQListView</name>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImportDialog</name>
    <message>
        <source>Create new Database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open file dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Corrects bad output style (gtktalog)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>csv files(*.csv)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>open file dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose a file for import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;strong&gt;Please read the README_IMPORT before you import!&lt;/strong&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>xml files(*.xml)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import CSV file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Correct bad style from gtktalog export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Separator:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This is the separator in dataline
&lt;path&gt;SEPARATOR&lt;size&gt;SEPARATOR&lt;date&gt;&lt;space&gt;&lt;time&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Separator in data line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Text (csv)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gtktalog &amp;XML</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;WhereIsIt XML (classic)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select the type of import here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select this for importing a text import (csv)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select this for importing a xml report generated frm gtktalog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open the file dialog for selecting file to import.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Corrects bad output style from gtktalog.
&lt;media&gt;SEPARATOR/&lt;dir&gt;/SEPARATOR/&lt;dir&gt;
 will be to
&lt;media&gt;/&lt;dir&gt;/&lt;dir&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must be fill the &quot;Filename&quot; field!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must be fill the &quot;Separator&quot; field!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>all files(*.*)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>InfoDialog</name>
    <message>
        <source>German translation &amp; additional programming</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Spanish translation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Czech translation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About cdcat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About Cdcat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Thanks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>-= CdCatalog by Hyper =-</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Version:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Author:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copyright (C) 2003 Peter Deak (GPL)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AVI reader plugin &amp; Polish translation</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PWw</name>
    <message>
        <source>Please Wait...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unreadable Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Catalog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown(DB)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DVD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>HardDisc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Floppy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NetworkDrv</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FlashDrv</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OtherDevice</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video:
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Total Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Framerate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>More Data:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Comments</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copyright</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Creation Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Engineer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Product</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Software</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Source</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subject</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Technician</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown/not implemented/broken header
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bitrate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Genre</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not a RIFF/AVI file OR header broken!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sample/s</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SelReadable</name>
    <message>
        <source>Select readable items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Read mp3 tags</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Store content of some files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>content size limit in kByte</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>; separated list of readable file patterns</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default tag</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Read mp3 technical info as comment (bitrate,freq,length...)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Read avi technical info as comment (codecs,lenhth,...)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShowContent</name>
    <message>
        <source>Content of %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Confirmation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove the file content from the database. (Warning: Unrecoverable!)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 kByte</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save this content to a new file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save content...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select a filename below</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>I can&apos;t rewrite the file: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error while saving...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sure to delete this file&apos;s content from the database?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>addDialog</name>
    <message>
        <source>Directory Browser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New Disk %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Media to the Database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose a directory to scan:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Serial number of Media:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Owner:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK / Scan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DVD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>HardDisc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Floppy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NetworkPlace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FlashDrive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OtherDevice</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must be fill the &quot;Name&quot; field!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Media Name must be unique! Please change it!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select readable items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Value of Serial Number must be unique! Please change it!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You haven&apos;t selected a directory! Please select one!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The media name can&apos;t begin with the &quot;@&quot; character!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>borrowDialog</name>
    <message>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>I borrow the &quot;%1&quot; named media to:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>I borrow the &quot;&quot; named media to:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Borrowing...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>borrowingDialog</name>
    <message>
        <source>Media borrowing info:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Borrowed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>where is it now?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set &quot;Yes&quot; or &quot;No&quot; !</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you save the changes?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure want to clear all borrow?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>I got it back!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;&lt; </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Borrowing info...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show only borrowed items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear all borrowing info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>commentEdit</name>
    <message>
        <source>Edit Comment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>exportCdcatDB</name>
    <message>
        <source>Availiable media</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media to export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All media</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>separator:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File to export:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filename missing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please enter a filename!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Separator missing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please enter a separator!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error during write config...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All files (*.*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>file chooser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose a file!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add media</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove media</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>export as HTML</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>export as CSV</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>I can&apos;t create or rewrite the file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export from cdcat:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export database...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>What to export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Only media name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Comment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>HTML headline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>table header</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Overwrite?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you want overwrite this file?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Discard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export CdCat database: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>findDialog</name>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search in the database...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close / Go to selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Find:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Seek in:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Owner:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Comment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>mp3-tag Comment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>mp3-tag Album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>mp3-tag Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>mp3-tag Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Case sensitive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use easy matching instead regex</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All/Everybody</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All media</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Content</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media / Directory name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>helpDialog</name>
    <message>
        <source>help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;p align=&quot;center&quot;&gt;&lt;font size=&quot;+1&quot;&gt;&lt;b&gt;Help&lt;/b&gt;&lt;/font&gt;&lt;/p&gt;&lt;br&gt;

&lt;b&gt;What&apos;s this?&lt;/b&gt;&lt;br&gt;
&lt;blockquote&gt;
The cdcat is graphical (QT based) multiplatform (Linux/Windows) catalog program which scans the directories/drives you want and memorize the filesystem including the tags of mp3&apos;s and other data and store it in a small file.
The database is stored in a gzipped XML format, so you can hack it, or use it if necessary :-)
And the program can store the content of some specified files up to a limit size if you want. (for example: *.nfo)
&lt;/blockquote&gt;
&lt;br&gt;
&lt;b&gt;Usage:&lt;/b&gt;&lt;br&gt;
&lt;blockquote&gt;
&lt;i&gt;Create a new catalog&lt;/i&gt;: Run the &lt;tt&gt;New&lt;/tt&gt; command in the catalog menu. You have to type the name of the new catalog. You can specify the default username of the media(which you scan later), and add a comment to the catalog.&lt;br&gt;Before the scanning select the necessary readable components in the config dialog, which can be mp3 tags content of some files or etc.  If you done this, you can scan one of your media with &lt;tt&gt;Add media&lt;/tt&gt;command in the Edit menu. In that dialog you have to specyfi the directory/or drive the media you want to add. It&apos;s recommended to specify the name and the number of the media which has to be unique. (The program always generate one identical name and number) You can label the media to a owner, if necessary.
&lt;br&gt;If you scanned your media, you will be able to browse in it with the browser window (like mc) , or search in it. You can save the catalog with &lt;tt&gt;save as&lt;/tt&gt; command in the Catalog menu.
&lt;br&gt;
&lt;br&gt;
&lt;i&gt;Open an existing catalog:&lt;/i&gt;Run the &lt;tt&gt;open&lt;/tt&gt; command in the Catalog menu, and choice the file of the catalog. (*.hcf)  After the opening you will be able browse the catalog or search in it.
&lt;br&gt;
&lt;/blockquote&gt;
&lt;br&gt;
&lt;b&gt;Author:&lt;/b&gt;
&lt;blockquote&gt;The program was written by  Peter Deak  (hungary)&lt;br&gt;
E-mail: hyperr@freemail.hu
&lt;br&gt;
&lt;/blockquote&gt;
&lt;br&gt;
&lt;b&gt;License:&lt;/b&gt;
&lt;blockquote&gt;General Public License (GPL)&lt;/blockquote&gt;
&lt;br&gt;
&lt;b&gt;Homepage:&lt;/b&gt;
&lt;blockquote&gt;You can read about the program and get new versions, sources etc, in the hompage of cdcat:&lt;br&gt;&lt;tt&gt;http://cdcat.sourceforge.net&lt;/tt&gt;&lt;/blockquote&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>importGtktalogCsv</name>
    <message>
        <source>Import was successful.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 media</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>media</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 directory:,
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>directories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>are imported.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import successful</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>file read error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not read file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fatal error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fatal error occured.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>file open error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not open file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>importuser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Importing CSV...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>importGtktalogXml</name>
    <message>
        <source>Importing XML...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>XML import was successful.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 media</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>media</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 directory:,
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>directories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>are imported.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import successful</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>parse error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>error during parsing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>importuser</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>importWhereIsItXml</name>
    <message>
        <source>Importing XML...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Importing XML from WhereIsIt was successful.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 media</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>media</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 directory:,
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>directories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>are imported.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import successful</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>parse error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>error during parsing</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>newdbdialog</name>
    <message>
        <source>DataBase&apos;s Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DataBase Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DataBase Owner:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Catalog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>hcat-user</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source></source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>renamedialog</name>
    <message>
        <source>Rename node...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Give the new name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The new (media) name must be unique!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The new media name can&apos;t starts with &quot;@&quot; !</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>renumberdialog</name>
    <message>
        <source>Error:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The element is NOT a Media!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Re-Number media...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Give the new serial number:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The new media-number must be unique!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please enter number value!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>seekEngine</name>
    <message>
        <source>Error in the pattern:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There is no matching.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>dir</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>media</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
